# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.12.3] - 2021-10-29
### Fixed
- `Model.insert_many` now supports `on_conflict`

## [0.12.1] - 2021-10-27
### Added

### Changed

### Removed


[Unreleased]: https://github.com/klen/peewee-aio/compare/0.12.3...HEAD
[0.12.3]: https://github.com/klen/peewee-aio/compare/0.12.1...0.12.3
[0.12.1]: https://github.com/klen/peewee-aio/compare/0.1.0...0.12.1
[0.1.0]: https://github.com/klen/peewee-aio/releases/tag/0.1.0

